C
C This file is issued from the MODULEF library, but has been 
C subsequently modified
C
      SUBROUTINE INITIS(M,LMM,IMPR,NNNN)
C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C BUT :
C -----
C INITIALISER UN ENCHAINEMENT MODULEF. 2 UTILITAIRES SONT DISPONIBLES :
C - INITI  : INITIALISATION AVEC LECTURE DU TITRE
C - INITIS :       ''       SANS        ''
C
C PARAMETRES D'ENTREE :
C ---------------------
C M      : SUPER TABLEAU DE TRAVAIL
C LMM    : NBRE DE MOTS DU SUPER TABLEAU DECLARE DANS PROGRAMME APPELANT
C IMPR   : PARAMETRE D'IMPRESSION
C NNNN   : PARAMETRE D'IMPRESSION DE L'ADRESSAGE DANS M DES TABLEAUX
C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C PROGRAMMEUR : A. PERRONNET LAN189 ET IRIA PARIS, NOVEMBRE 1979
C     ADAPTATION FORTRAN 77 PAR P. LAUG, INRIA,    JUIN     1983
C ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
      CHARACTER LIGNE*256,CHACMD*1,KDATE*6,KCREAT*24,KINFO*80
      DIMENSION M(*)
      COMMON /LIBCHA/ LIGNE,CHACMD
      COMMON /LIBINT/ MPFIC(16),MPLIG(16),IPILE,ILIGNE,ISOUFF,IRETAP
      COMMON /TRAVAI/ IM,LM,NOMTAB,NNN,NZ(1020)
      COMMON /TRAVA1/ NTITRE(20),NDATE(2),NOMCRE(6),LONREE,IMPRE,
     +                IMPLEC,LECSUI,IFILL
      COMMON /UNITES/ LECT,IMPRIM,INTERA,IMPFIC,NFSAUV
      COMMON /COMDIR/ MLON(0:99),MPGE(0:99),MPGD(0:99)
C
C IMPRIMANTE
      IMPRIM = IINFO('IMPRIMANTE INITIALE')
      IF (IMPR.NE.0) WRITE (IMPRIM,1000)
C
C TRAITEMENT BATCH OU INTERACTIF ?
      INTERA = IINFO('INTERACTIVITE INITIALE')
C
C INITIALISATIONS EN BATCH
C     IF (INTERA .EQ. 0) THEN
C
C INITIALISATIONS EN INTERACTIF
C     ELSE
C     END IF
C
C INITIALISATIONS COMMUNES (BATCH OU INTERACTIF)
      LECT     = IINFO('LECTEUR INITIAL')
      IMPFIC   = 99
      NFSAUV   = 0
      CHACMD   = '%'
      MPFIC(1) = LECT
      MPLIG(1) = 0
      IPILE    = 1
      ILIGNE   = 256
      ISOUFF   = 0
      IRETAP   = 0
C
C INITIALISATION DU FORMAT LIBRE 86
      I=LIBACT(-2)
      II = I*2
C
C     IL EST POSSIBLE D INCLURE IC UN SP LANGAGE MACHINE QUI RECUPERE
C     LA 1-ERE ADRESSE LIBRE DE LA PLUS GRANDE ZONE MEMOIRE CENTRALE
C     DISPONIBLE DANS LA REGION DEMANDEE ET DE L AFFECTER A M ET LE
C     NOMBRE DE MOTS A LMM
C
      IM     = 1
      LM     = LMM
      NOMTAB = 0
      NNN    = NNNN
      LONREE = 1
      IMPRE  = IMPR
      IMPLEC = 0
      LECSUI = 0
      DO 50 I = 0,99
   50 MLON(I) = 0
C
C INITIALISATION DE L'ALLOCATEUR DYNAMIQUE 86
      CALL PRALDY(M,LM)
C
C TITRE
      IBLANC = ICHAR4('    ')
      DO 100 I = 1,20
  100 NTITRE(I) = IBLANC
C
C DATE
      KDATE = KINFO('DATE')
      NDATE(1) = ICHAR4(KDATE(5:6) // '/' // KDATE(3:3))
      NDATE(2) = ICHAR4(KDATE(4:4) // '/' // KDATE(1:2))
      IF (IMPR.NE.0) WRITE (IMPRIM,1010) NDATE
C
C NOM DE L'UTILISATEUR
      KCREAT = KINFO('UTILISATEUR')
      DO 200 I = 1,6
  200 NOMCRE(I) = ICHAR4(KCREAT(4*I-3:4*I))
      IF (IMPR.NE.0) WRITE (IMPRIM,1020) NOMCRE
C
C FICHIER DE DEMARRAGE MODULEF (STARTUP)
      IMPRE = 0
CC      CALL TRUNIT(IUNIT)
CC      CALL OUVRIR(IUNIT,'MODULEF.D','OLD,FORMATTED',0,IOSTAT)
CC      IF (IOSTAT.EQ.0) CALL LECTEU(IUNIT)
      IMPRE  = IMPR
C
C1000 FORMAT(/' M   M    OOO    DDDD    U   U   L       EEEEE   FFFFF'  #GB
C    +       /' MM MM   O   O   D   D   U   U   L       E       F'      #GB
C    +       /' M M M   O   O   D   D   U   U   L       EEEE    FFFF'   #GB
C    +       /' M   M   O   O   D   D   U   U   L       E       F'      #GB
C    +       /' M   M    OOO    DDDD     UUU    LLLLL   EEEEE   F',     #GB
C    +        '      VERSION 92'/)                                      #GB
C1010 FORMAT(' DATE   : ',2A4 )                                         #GB
C1020 FORMAT(' AUTHOR : ',8A4 )                                         #GB
C
 1000 FORMAT(/' M   M    OOO    DDDD    U   U   L       EEEEE   FFFFF'  #F
     +       /' MM MM   O   O   D   D   U   U   L       E       F'      #F
     +       /' M M M   O   O   D   D   U   U   L       EEEE    FFFF'   #F
     +       /' M   M   O   O   D   D   U   U   L       E       F'      #F
     +       /' M   M    OOO    DDDD     UUU    LLLLL   EEEEE   F',     #F
     +        '      VERSION 92'/)                                      #F
 1010 FORMAT(' DATE   : ',2A4)                                          #F
 1020 FORMAT(' AUTEUR : ',8A4)                                          #F
C
      END
